function Experiment1(p)
%EXPERIMENT1    Test the conditioning of different linearizations on the
% scalar polynomial p. 
%
% This script can be used to perform numerical experiments similar to the
% one in the paper "On a class of matrix pencils equivalent to a given
% matrix polynomial". 

% Frobenius linearization
F = compan (p);

[v,l] = newtpol(p);
b = [];
for i = 1 : length(l)
  b = [ b , exp(2*pi*1i * (1:l(i)) ./ l(i)) * v(i) ];
end

A = seccomp(b, p);

% Secular linearization using the roots of p slightly perturbed
x = roots(p);
n = length(x);
b2 = x .* (1 + 1e-12 * randn(n,1));

A2 = seccomp(b2, p);

t = 1 : n;

semilogy(t,condeig(F),t,condeig(A),t,condeig(A2));
legend('Frobenius', 'Tropical', 'Perturbed eigenvalues');
xlabel('roots');
ylabel('Conditioning')

end
